update to 5.0.0 beta1

f41
David Tardon 10 years ago
parent 61085be023
commit fd5883b58c

13
.gitignore vendored

@ -22,7 +22,7 @@
/d6eef4b4cacb2183f2bf265a5a03a354-boost_1_55_0.tar.bz2
/Firebird-2.5.2.26540-0.tar.bz2
/OpenCOLLADA-master-6509aa13af.tar.bz2
/harfbuzz-0.9.23.tar.bz2
/harfbuzz-0.9.40.tar.bz2
/language-subtag-registry-2014-12-03.tar.bz2
/lcms2-2.6.tar.gz
/libabw-0.1.1.tar.bz2
@ -30,18 +30,18 @@
/libcdr-0.1.1.tar.bz2
/libe-book-0.1.1.tar.bz2
/libeot-0.01.tar.bz2
/libetonyek-0.1.1.tar.bz2
/libetonyek-0.1.2.tar.bz2
/libfreehand-0.1.0.tar.bz2
/libgltf-0.0.2.tar.bz2
/libmspub-0.1.2.tar.bz2
/libmwaw-0.3.4.tar.bz2
/libodfgen-0.1.3.tar.bz2
/libmwaw-0.3.5.tar.bz2
/libodfgen-0.1.4.tar.bz2
/libpagemaker-0.0.2.tar.bz2
/libvisio-0.1.1.tar.bz2
/librevenge-0.0.2.tar.bz2
/libwpd-0.10.0.tar.bz2
/libwpg-0.3.0.tar.bz2
/libwps-0.3.1.tar.bz2
/libwps-0.4.0.tar.bz2
/libreoffice-4.4.0.0.beta2.tar.xz
/libreoffice-help-4.4.0.0.beta2.tar.xz
/libreoffice-translations-4.4.0.0.beta2.tar.xz
@ -69,3 +69,6 @@
/libreoffice-5.0.0.0.alpha1.tar.xz
/libreoffice-help-5.0.0.0.alpha1.tar.xz
/libreoffice-translations-5.0.0.0.alpha1.tar.xz
/libreoffice-5.0.0.0.beta1.tar.xz
/libreoffice-help-5.0.0.0.beta1.tar.xz
/libreoffice-translations-5.0.0.0.beta1.tar.xz

@ -1,73 +0,0 @@
From 62ccbdf2233e10e70909a080f09465982a504474 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Wed, 5 Nov 2014 13:49:07 +0000
Subject: [PATCH] Resolves: fdo#37559 revert adding extra dummy polygons to get
better gradients
Change-Id: I38b8e7cb79540a99696ac09e4061c9d87440b2b2
---
drawinglayer/source/primitive2d/polygonprimitive2d.cxx | 3 +--
svx/source/customshapes/EnhancedCustomShape2d.cxx | 16 ----------------
svx/source/customshapes/EnhancedCustomShapeFontWork.cxx | 2 +-
3 files changed, 2 insertions(+), 19 deletions(-)
diff --git a/drawinglayer/source/primitive2d/polygonprimitive2d.cxx b/drawinglayer/source/primitive2d/polygonprimitive2d.cxx
index 4a2944b..85b118f 100644
--- a/drawinglayer/source/primitive2d/polygonprimitive2d.cxx
+++ b/drawinglayer/source/primitive2d/polygonprimitive2d.cxx
@@ -526,11 +526,10 @@ namespace drawinglayer
{
// copy local polygon, it may be changed
basegfx::B2DPolygon aLocalPolygon(getB2DPolygon());
- aLocalPolygon.removeDoublePoints();
basegfx::B2DPolyPolygon aArrowA;
basegfx::B2DPolyPolygon aArrowB;
- if(!aLocalPolygon.isClosed() && aLocalPolygon.count() > 1)
+ if(!aLocalPolygon.isClosed())
{
// apply arrows
const double fPolyLength(basegfx::tools::getLength(aLocalPolygon));
diff --git a/svx/source/customshapes/EnhancedCustomShape2d.cxx b/svx/source/customshapes/EnhancedCustomShape2d.cxx
index 1e0e818..64e08d9 100644
--- a/svx/source/customshapes/EnhancedCustomShape2d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape2d.cxx
@@ -1902,22 +1902,6 @@ void EnhancedCustomShape2d::CreateSubPath( sal_uInt16& rSrcPt, sal_uInt16& rSegm
if(aNewB2DPolyPolygon.count())
{
- if( !bLineGeometryNeededOnly )
- {
- // hack aNewB2DPolyPolygon to fill logic rect - this is
- // needed to produce gradient fills that look like mso
- aNewB2DPolygon.clear();
- aNewB2DPolygon.append(basegfx::B2DPoint(0,0));
- aNewB2DPolygon.setClosed(true);
- aNewB2DPolyPolygon.append(aNewB2DPolygon);
-
- aNewB2DPolygon.clear();
- aNewB2DPolygon.append(basegfx::B2DPoint(aLogicRect.GetWidth(),
- aLogicRect.GetHeight()));
- aNewB2DPolygon.setClosed(true);
- aNewB2DPolyPolygon.append(aNewB2DPolygon);
- }
-
// #i37011#
bool bForceCreateTwoObjects(false);
diff --git a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
index 7332449..fba8740 100644
--- a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
@@ -606,7 +606,7 @@ void InsertMissingOutlinePoints( const Polygon& /*rOutlinePoly*/, const std::vec
void GetPoint( const Polygon& rPoly, const std::vector< double >& rDistances, const double& fX, double& fx1, double& fy1 )
{
fy1 = fx1 = 0.0;
- if ( rPoly.GetSize() > 1 )
+ if ( rPoly.GetSize() )
{
std::vector< double >::const_iterator aIter = std::lower_bound( rDistances.begin(), rDistances.end(), fX );
sal_uInt16 nIdx = sal::static_int_cast<sal_uInt16>( std::distance( rDistances.begin(), aIter ) );
--
1.9.3

@ -1,49 +0,0 @@
From 71c00b3e96fb639e0ff0815608827936219adac5 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Mon, 23 Mar 2015 10:41:21 +0000
Subject: [PATCH] Resolves: rhbz#1204244 group sdb windows together as 'base'
Change-Id: Ie0d17e562b24a8108d79d13592fff3bf2b9a6713
---
framework/source/helper/titlebarupdate.cxx | 20 ++++++--------------
1 file changed, 6 insertions(+), 14 deletions(-)
diff --git a/framework/source/helper/titlebarupdate.cxx b/framework/source/helper/titlebarupdate.cxx
index 7626309..b79b5b2 100644
--- a/framework/source/helper/titlebarupdate.cxx
+++ b/framework/source/helper/titlebarupdate.cxx
@@ -139,25 +139,17 @@ void TitleBarUpdate::impl_updateApplicationID(const css::uno::Reference< css::fr
OUString sDesktopName;
OUString aModuleId = xModuleManager->identify(xFrame);
- if ( aModuleId == "com.sun.star.text.TextDocument" ||
- aModuleId == "com.sun.star.text.GlobalDocument" ||
- aModuleId == "com.sun.star.text.WebDocument" ||
- aModuleId == "com.sun.star.xforms.XMLFormDocument" )
+ if ( aModuleId.startsWith("com.sun.star.text.") || aModuleId.startsWith("com.sun.star.xforms.") )
sDesktopName = "Writer";
- else if ( aModuleId == "com.sun.star.sheet.SpreadsheetDocument" )
+ else if ( aModuleId.startsWith("com.sun.star.sheet.") )
sDesktopName = "Calc";
- else if ( aModuleId == "com.sun.star.presentation.PresentationDocument" )
+ else if ( aModuleId.startsWith("com.sun.star.presentation.") )
sDesktopName = "Impress";
- else if ( aModuleId == "com.sun.star.drawing.DrawingDocument" )
+ else if ( aModuleId.startsWith("com.sun.star.drawing." ) )
sDesktopName = "Draw";
- else if ( aModuleId == "com.sun.star.formula.FormulaProperties" )
+ else if ( aModuleId.startsWith("com.sun.star.formula." ) )
sDesktopName = "Math";
- else if ( aModuleId == "com.sun.star.sdb.DatabaseDocument" ||
- aModuleId == "com.sun.star.sdb.OfficeDatabaseDocument" ||
- aModuleId == "com.sun.star.sdb.RelationDesign" ||
- aModuleId == "com.sun.star.sdb.QueryDesign" ||
- aModuleId == "com.sun.star.sdb.TableDesign" ||
- aModuleId == "com.sun.star.sdb.DataSourceBrowser" )
+ else if ( aModuleId.startsWith("com.sun.star.sdb.") )
sDesktopName = "Base";
else
sDesktopName = "Startcenter";
--
1.9.3

@ -1,34 +0,0 @@
From 3c22024f41029dd4c1dca6b265d1fd0f14fc2f95 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Thu, 26 Mar 2015 13:37:10 +0000
Subject: [PATCH] Resolves: tdf#90256 repair invalid docking positions
Change-Id: If144a867dc4be6975c08cd1eea9ebb540975aafc
---
framework/source/layoutmanager/layoutmanager.cxx | 9 ++++++++-
1 file changed, 8 insertions(+), 1 deletion(-)
diff --git a/framework/source/layoutmanager/layoutmanager.cxx b/framework/source/layoutmanager/layoutmanager.cxx
index d4e4eee..94e99ff 100644
--- a/framework/source/layoutmanager/layoutmanager.cxx
+++ b/framework/source/layoutmanager/layoutmanager.cxx
@@ -531,8 +531,15 @@ bool LayoutManager::readWindowStateData( const OUString& aName, UIElement& rElem
else if ( aWindowState[n].Name == WINDOWSTATE_PROPERTY_DOCKPOS )
{
awt::Point aPoint;
- if ( aWindowState[n].Value >>= aPoint )
+ if (aWindowState[n].Value >>= aPoint)
+ {
+ //tdf#90256 repair these broken Docking positions
+ if (aPoint.X < 0)
+ aPoint.X = SAL_MAX_INT32;
+ if (aPoint.Y < 0)
+ aPoint.Y = SAL_MAX_INT32;
rElementData.m_aDockedData.m_aPos = aPoint;
+ }
}
else if ( aWindowState[n].Name == WINDOWSTATE_PROPERTY_POS )
{
--
1.9.3

@ -1,139 +0,0 @@
From 5bf5fb4567096680d417af37744c743f00e26eeb Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Wed, 14 Jan 2015 16:55:02 +0000
Subject: [PATCH] Use the same advanced Ellipse and Rectangle shapes in writer
as draw
i.e. reconcile writer with draw/impress wrt.
commit 0e9faf7a0f8c76b50d9a9354d5fab5d1ad4af821
Author: Petr Mladek <pmladek@suse.cz>
Date: Fri Apr 22 16:51:58 2011 +0200
sd-toolbar-advanced-shapes.diff: used advanced Ellipse and Rectangle shapes
they allow to wrap text according to the shape which is a very nice
feature (bnc#171052)
Change-Id: I0bddfe65030f3515bcb5a30f2886d3ad17a72b0d
---
sw/uiconfig/sglobal/toolbar/drawbar.xml | 6 +++---
sw/uiconfig/swform/toolbar/drawbar.xml | 6 +++---
sw/uiconfig/swreport/toolbar/drawbar.xml | 6 +++---
sw/uiconfig/swriter/toolbar/drawbar.xml | 6 +++---
sw/uiconfig/swxform/toolbar/drawbar.xml | 6 +++---
5 files changed, 15 insertions(+), 15 deletions(-)
diff --git a/sw/uiconfig/sglobal/toolbar/drawbar.xml b/sw/uiconfig/sglobal/toolbar/drawbar.xml
index 8731a05..b31c198 100644
--- a/sw/uiconfig/sglobal/toolbar/drawbar.xml
+++ b/sw/uiconfig/sglobal/toolbar/drawbar.xml
@@ -21,8 +21,8 @@
<toolbar:toolbaritem xlink:href=".uno:SelectObject" toolbar:helpid="10128"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:Line" toolbar:helpid="10102"/>
- <toolbar:toolbaritem xlink:href=".uno:Rect" toolbar:helpid="10104"/>
- <toolbar:toolbaritem xlink:href=".uno:Ellipse" toolbar:helpid="10110"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.rectangle" toolbar:helpid="10104"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.ellipse" toolbar:helpid="10110"/>
<toolbar:toolbaritem xlink:href=".uno:Polygon_Unfilled" toolbar:visible="false" toolbar:helpid="10395"/>
<toolbar:toolbaritem xlink:href=".uno:Bezier_Unfilled" toolbar:visible="false" toolbar:helpid="10397"/>
<toolbar:toolbaritem xlink:href=".uno:Freeline_Unfilled" toolbar:helpid="10464"/>
@@ -48,4 +48,4 @@
<toolbar:toolbaritem xlink:href=".uno:InsertGraphic" toolbar:helpid="10241"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:ExtrusionToggle" toolbar:helpid="10960"/>
-</toolbar:toolbar>
\ No newline at end of file
+</toolbar:toolbar>
diff --git a/sw/uiconfig/swform/toolbar/drawbar.xml b/sw/uiconfig/swform/toolbar/drawbar.xml
index 8731a05..b31c198 100644
--- a/sw/uiconfig/swform/toolbar/drawbar.xml
+++ b/sw/uiconfig/swform/toolbar/drawbar.xml
@@ -21,8 +21,8 @@
<toolbar:toolbaritem xlink:href=".uno:SelectObject" toolbar:helpid="10128"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:Line" toolbar:helpid="10102"/>
- <toolbar:toolbaritem xlink:href=".uno:Rect" toolbar:helpid="10104"/>
- <toolbar:toolbaritem xlink:href=".uno:Ellipse" toolbar:helpid="10110"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.rectangle" toolbar:helpid="10104"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.ellipse" toolbar:helpid="10110"/>
<toolbar:toolbaritem xlink:href=".uno:Polygon_Unfilled" toolbar:visible="false" toolbar:helpid="10395"/>
<toolbar:toolbaritem xlink:href=".uno:Bezier_Unfilled" toolbar:visible="false" toolbar:helpid="10397"/>
<toolbar:toolbaritem xlink:href=".uno:Freeline_Unfilled" toolbar:helpid="10464"/>
@@ -48,4 +48,4 @@
<toolbar:toolbaritem xlink:href=".uno:InsertGraphic" toolbar:helpid="10241"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:ExtrusionToggle" toolbar:helpid="10960"/>
-</toolbar:toolbar>
\ No newline at end of file
+</toolbar:toolbar>
diff --git a/sw/uiconfig/swreport/toolbar/drawbar.xml b/sw/uiconfig/swreport/toolbar/drawbar.xml
index 8731a05..b31c198 100644
--- a/sw/uiconfig/swreport/toolbar/drawbar.xml
+++ b/sw/uiconfig/swreport/toolbar/drawbar.xml
@@ -21,8 +21,8 @@
<toolbar:toolbaritem xlink:href=".uno:SelectObject" toolbar:helpid="10128"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:Line" toolbar:helpid="10102"/>
- <toolbar:toolbaritem xlink:href=".uno:Rect" toolbar:helpid="10104"/>
- <toolbar:toolbaritem xlink:href=".uno:Ellipse" toolbar:helpid="10110"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.rectangle" toolbar:helpid="10104"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.ellipse" toolbar:helpid="10110"/>
<toolbar:toolbaritem xlink:href=".uno:Polygon_Unfilled" toolbar:visible="false" toolbar:helpid="10395"/>
<toolbar:toolbaritem xlink:href=".uno:Bezier_Unfilled" toolbar:visible="false" toolbar:helpid="10397"/>
<toolbar:toolbaritem xlink:href=".uno:Freeline_Unfilled" toolbar:helpid="10464"/>
@@ -48,4 +48,4 @@
<toolbar:toolbaritem xlink:href=".uno:InsertGraphic" toolbar:helpid="10241"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:ExtrusionToggle" toolbar:helpid="10960"/>
-</toolbar:toolbar>
\ No newline at end of file
+</toolbar:toolbar>
diff --git a/sw/uiconfig/swriter/toolbar/drawbar.xml b/sw/uiconfig/swriter/toolbar/drawbar.xml
index 8731a05..b31c198 100644
--- a/sw/uiconfig/swriter/toolbar/drawbar.xml
+++ b/sw/uiconfig/swriter/toolbar/drawbar.xml
@@ -21,8 +21,8 @@
<toolbar:toolbaritem xlink:href=".uno:SelectObject" toolbar:helpid="10128"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:Line" toolbar:helpid="10102"/>
- <toolbar:toolbaritem xlink:href=".uno:Rect" toolbar:helpid="10104"/>
- <toolbar:toolbaritem xlink:href=".uno:Ellipse" toolbar:helpid="10110"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.rectangle" toolbar:helpid="10104"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.ellipse" toolbar:helpid="10110"/>
<toolbar:toolbaritem xlink:href=".uno:Polygon_Unfilled" toolbar:visible="false" toolbar:helpid="10395"/>
<toolbar:toolbaritem xlink:href=".uno:Bezier_Unfilled" toolbar:visible="false" toolbar:helpid="10397"/>
<toolbar:toolbaritem xlink:href=".uno:Freeline_Unfilled" toolbar:helpid="10464"/>
@@ -48,4 +48,4 @@
<toolbar:toolbaritem xlink:href=".uno:InsertGraphic" toolbar:helpid="10241"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:ExtrusionToggle" toolbar:helpid="10960"/>
-</toolbar:toolbar>
\ No newline at end of file
+</toolbar:toolbar>
diff --git a/sw/uiconfig/swxform/toolbar/drawbar.xml b/sw/uiconfig/swxform/toolbar/drawbar.xml
index 8731a05..b31c198 100644
--- a/sw/uiconfig/swxform/toolbar/drawbar.xml
+++ b/sw/uiconfig/swxform/toolbar/drawbar.xml
@@ -21,8 +21,8 @@
<toolbar:toolbaritem xlink:href=".uno:SelectObject" toolbar:helpid="10128"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:Line" toolbar:helpid="10102"/>
- <toolbar:toolbaritem xlink:href=".uno:Rect" toolbar:helpid="10104"/>
- <toolbar:toolbaritem xlink:href=".uno:Ellipse" toolbar:helpid="10110"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.rectangle" toolbar:helpid="10104"/>
+ <toolbar:toolbaritem xlink:href=".uno:BasicShapes.ellipse" toolbar:helpid="10110"/>
<toolbar:toolbaritem xlink:href=".uno:Polygon_Unfilled" toolbar:visible="false" toolbar:helpid="10395"/>
<toolbar:toolbaritem xlink:href=".uno:Bezier_Unfilled" toolbar:visible="false" toolbar:helpid="10397"/>
<toolbar:toolbaritem xlink:href=".uno:Freeline_Unfilled" toolbar:helpid="10464"/>
@@ -48,4 +48,4 @@
<toolbar:toolbaritem xlink:href=".uno:InsertGraphic" toolbar:helpid="10241"/>
<toolbar:toolbarseparator/>
<toolbar:toolbaritem xlink:href=".uno:ExtrusionToggle" toolbar:helpid="10960"/>
-</toolbar:toolbar>
\ No newline at end of file
+</toolbar:toolbar>
--
1.9.3

@ -1,56 +0,0 @@
From c11b6b64f63b3c7f8f8bb0f1857a9c7d8748ba9c Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Thu, 12 Mar 2015 15:42:23 +0100
Subject: [PATCH] add accel. to switch monitors to pres. console
Change-Id: I86c458f2c0a1c6a6baa6461a44b68c5f48ea55b0
---
officecfg/registry/data/org/openoffice/Office/PresenterScreen.xcu | 8 ++++++++
sdext/source/presenter/PresenterController.cxx | 5 ++++-
2 files changed, 12 insertions(+), 1 deletion(-)
diff --git a/officecfg/registry/data/org/openoffice/Office/PresenterScreen.xcu b/officecfg/registry/data/org/openoffice/Office/PresenterScreen.xcu
index 3eb6434..26d9483 100644
--- a/officecfg/registry/data/org/openoffice/Office/PresenterScreen.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/PresenterScreen.xcu
@@ -969,6 +969,14 @@
<value xml:lang="en-US">Shows the Slides Overview</value>
</prop>
</node>
+ <node oor:name="x" oor:op="replace">
+ <prop oor:name="Left">
+ <value xml:lang="en-US">Ctrl-'4'</value>
+ </prop>
+ <prop oor:name="Right">
+ <value xml:lang="en-US">Switches monitors</value>
+ </prop>
+ </node>
</node>
</node>
</node>
--
2.3.1

@ -1,30 +0,0 @@
From 75155bcf07d296352162d0b963493b4ba0238cca Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Mon, 18 May 2015 12:21:49 +0200
Subject: [PATCH] add missing includes
Change-Id: I2b091eb8c407f032f15674338c917bbe7e06d15b
---
vcl/unx/generic/gdi/cairotextrender.cxx | 2 ++
1 file changed, 2 insertions(+)
diff --git a/vcl/unx/generic/gdi/cairotextrender.cxx b/vcl/unx/generic/gdi/cairotextrender.cxx
index 24192da..20fcc1d 100644
--- a/vcl/unx/generic/gdi/cairotextrender.cxx
+++ b/vcl/unx/generic/gdi/cairotextrender.cxx
@@ -22,10 +22,12 @@
#include <basegfx/polygon/b2dpolypolygon.hxx>
#include <vcl/settings.hxx>
#include <vcl/sysdata.hxx>
+#include <vcl/svapp.hxx>
#include "generic/printergfx.hxx"
#include "generic/genpspgraphics.h"
#include "generic/geninst.h"
+#include "generic/glyphcache.hxx"
#include "PhysicalFontFace.hxx"
#include "impfont.hxx"
--
2.4.0

@ -1,432 +0,0 @@
From 7adf5a76404205e3b2f1dbb4bb01a612d78ea0dc Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Tue, 13 Jan 2015 13:55:58 +0000
Subject: [PATCH] allow comparing documents which only differ by frame contents
if two documents have the same number of frames then have an additional stab at
comparing the contents of those frames
Change-Id: Ie7f1a8906d49d720a74620ad8d69fd97c76304e3
(cherry picked from commit 16916a14a2ce382aa4ff2a25f8e477108aba5a67)
---
sw/source/core/doc/doccomp.cxx | 236 +++++++++++++++++++++++++----------------
1 file changed, 144 insertions(+), 92 deletions(-)
diff --git a/sw/source/core/doc/doccomp.cxx b/sw/source/core/doc/doccomp.cxx
index 8634835..043d2d4 100644
--- a/sw/source/core/doc/doccomp.cxx
+++ b/sw/source/core/doc/doccomp.cxx
@@ -38,6 +38,7 @@
#include <section.hxx>
#include <tox.hxx>
#include <docsh.hxx>
+#include <fmtcntnt.hxx>
#include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
#include <com/sun/star/document/XDocumentProperties.hpp>
@@ -65,18 +66,32 @@ public:
class CompareData
{
+protected:
+ SwDoc& rDoc;
+private:
size_t* pIndex;
bool* pChangedFlag;
-protected:
+ SwPaM *pInsRing, *pDelRing;
+
+ sal_uLong PrevIdx( const SwNode* pNd );
+ sal_uLong NextIdx( const SwNode* pNd );
+
vector< CompareLine* > aLines;
sal_uLong nSttLineNum;
+ bool m_bRecordDiff;
// Truncate beginning and end and add all others to the LinesArray
- virtual void CheckRanges( CompareData& ) = 0;
+ void CheckRanges( CompareData& );
+
+ virtual const SwNode& GetEndOfContent() = 0;
public:
- CompareData();
+ CompareData(SwDoc& rD, bool bRecordDiff)
+ : rDoc( rD ), pIndex( 0 ), pChangedFlag( 0 ), pInsRing(0), pDelRing(0)
+ , nSttLineNum( 0 ), m_bRecordDiff(bRecordDiff)
+ {
+ }
virtual ~CompareData();
// Are there differences?
@@ -89,10 +104,10 @@ public:
// Displaying the actually content is to be handled by the subclass!
sal_uLong ShowDiffs( const CompareData& rData );
- virtual void ShowInsert( sal_uLong nStt, sal_uLong nEnd );
- virtual void ShowDelete( const CompareData& rData, sal_uLong nStt,
+ void ShowInsert( sal_uLong nStt, sal_uLong nEnd );
+ void ShowDelete( const CompareData& rData, sal_uLong nStt,
sal_uLong nEnd, sal_uLong nInsPos );
- virtual void CheckForChangesInLine( const CompareData& rData,
+ void CheckForChangesInLine( const CompareData& rData,
sal_uLong& nStt, sal_uLong& nEnd,
sal_uLong& nThisStt, sal_uLong& nThisEnd );
@@ -114,6 +129,38 @@ public:
{ return aLines[ nLine ]; }
void InsertLine( CompareLine* pLine )
{ aLines.push_back( pLine ); }
+
+ void SetRedlinesToDoc( bool bUseDocInfo );
+};
+
+class CompareMainText : public CompareData
+{
+public:
+ CompareMainText(SwDoc &rD, bool bRecordDiff=true)
+ : CompareData(rD, bRecordDiff)
+ {
+ }
+
+ virtual const SwNode& GetEndOfContent() SAL_OVERRIDE
+ {
+ return rDoc.GetNodes().GetEndOfContent();
+ }
+};
+
+class CompareFrmFmtText : public CompareData
+{
+ const SwNodeIndex &m_rIndex;
+public:
+ CompareFrmFmtText(SwDoc &rD, const SwNodeIndex &rIndex, bool bRecordDiff=true)
+ : CompareData(rD, bRecordDiff)
+ , m_rIndex(rIndex)
+ {
+ }
+
+ virtual const SwNode& GetEndOfContent() SAL_OVERRIDE
+ {
+ return *m_rIndex.GetNode().EndOfSectionNode();
+ }
};
class Hash
@@ -328,13 +375,21 @@ public:
CompareLine::~CompareLine() {}
-CompareData::CompareData()
- : pIndex( 0 ), pChangedFlag( 0 ), nSttLineNum( 0 )
-{
-}
-
CompareData::~CompareData()
{
+ if( pDelRing )
+ {
+ while( pDelRing->GetNext() != pDelRing )
+ delete pDelRing->GetNext();
+ delete pDelRing;
+ }
+ if( pInsRing )
+ {
+ while( pInsRing->GetNext() != pInsRing )
+ delete pInsRing->GetNext();
+ delete pInsRing;
+ }
+
delete[] pIndex;
delete[] pChangedFlag;
}
@@ -393,9 +448,12 @@ sal_uLong CompareData::ShowDiffs( const CompareData& rData )
while( nStt1 < nLen1 && rData.GetChanged( nStt1 )) ++nStt1;
while( nStt2 < nLen2 && GetChanged( nStt2 )) ++nStt2;
- // Check if there are changed lines (only slightly different) and
- // compare them in detail.
- CheckForChangesInLine( rData, nSav1, nStt1, nSav2, nStt2 );
+ if (m_bRecordDiff)
+ {
+ // Check if there are changed lines (only slightly different) and
+ // compare them in detail.
+ CheckForChangesInLine( rData, nSav1, nStt1, nSav2, nStt2 );
+ }
++nCnt;
}
@@ -422,19 +480,6 @@ bool CompareData::HasDiffs( const CompareData& rData ) const
return bRet;
}
-void CompareData::ShowInsert( sal_uLong, sal_uLong )
-{
-}
-
-void CompareData::ShowDelete( const CompareData&, sal_uLong, sal_uLong, sal_uLong )
-{
-}
-
-void CompareData::CheckForChangesInLine( const CompareData& ,
- sal_uLong&, sal_uLong&, sal_uLong&, sal_uLong& )
-{
-}
-
Hash::Hash( sal_uLong nSize )
: nCount(1)
{
@@ -972,30 +1017,6 @@ public:
OUString GetText() const;
};
-class SwCompareData : public CompareData
-{
- SwDoc& rDoc;
- SwPaM *pInsRing, *pDelRing;
-
- sal_uLong PrevIdx( const SwNode* pNd );
- sal_uLong NextIdx( const SwNode* pNd );
-
- virtual void CheckRanges( CompareData& ) SAL_OVERRIDE;
- virtual void ShowInsert( sal_uLong nStt, sal_uLong nEnd ) SAL_OVERRIDE;
- virtual void ShowDelete( const CompareData& rData, sal_uLong nStt,
- sal_uLong nEnd, sal_uLong nInsPos ) SAL_OVERRIDE;
-
- virtual void CheckForChangesInLine( const CompareData& rData,
- sal_uLong& nStt, sal_uLong& nEnd,
- sal_uLong& nThisStt, sal_uLong& nThisEnd ) SAL_OVERRIDE;
-
-public:
- SwCompareData( SwDoc& rD ) : rDoc( rD ), pInsRing(0), pDelRing(0) {}
- virtual ~SwCompareData();
-
- void SetRedlinesToDoc( bool bUseDocInfo );
-};
-
SwCompareLine::SwCompareLine( const SwNode& rNd )
: rNode( rNd )
{
@@ -1400,23 +1421,7 @@ bool SwCompareLine::ChangesInLine( const SwCompareLine& rLine,
return bRet;
}
-SwCompareData::~SwCompareData()
-{
- if( pDelRing )
- {
- while( pDelRing->GetNext() != pDelRing )
- delete pDelRing->GetNext();
- delete pDelRing;
- }
- if( pInsRing )
- {
- while( pInsRing->GetNext() != pInsRing )
- delete pInsRing->GetNext();
- delete pInsRing;
- }
-}
-
-sal_uLong SwCompareData::NextIdx( const SwNode* pNd )
+sal_uLong CompareData::NextIdx( const SwNode* pNd )
{
if( pNd->IsStartNode() )
{
@@ -1430,7 +1435,7 @@ sal_uLong SwCompareData::NextIdx( const SwNode* pNd )
return pNd->GetIndex() + 1;
}
-sal_uLong SwCompareData::PrevIdx( const SwNode* pNd )
+sal_uLong CompareData::PrevIdx( const SwNode* pNd )
{
if( pNd->IsEndNode() )
{
@@ -1444,13 +1449,13 @@ sal_uLong SwCompareData::PrevIdx( const SwNode* pNd )
return pNd->GetIndex() - 1;
}
-void SwCompareData::CheckRanges( CompareData& rData )
+void CompareData::CheckRanges( CompareData& rData )
{
- const SwNodes& rSrcNds = static_cast<SwCompareData&>(rData).rDoc.GetNodes();
+ const SwNodes& rSrcNds = rData.rDoc.GetNodes();
const SwNodes& rDstNds = rDoc.GetNodes();
- const SwNode& rSrcEndNd = rSrcNds.GetEndOfContent();
- const SwNode& rDstEndNd = rDstNds.GetEndOfContent();
+ const SwNode& rSrcEndNd = rData.GetEndOfContent();
+ const SwNode& rDstEndNd = GetEndOfContent();
sal_uLong nSrcSttIdx = NextIdx( rSrcEndNd.StartOfSectionNode() );
sal_uLong nSrcEndIdx = rSrcEndNd.GetIndex();
@@ -1497,7 +1502,7 @@ void SwCompareData::CheckRanges( CompareData& rData )
}
}
-void SwCompareData::ShowInsert( sal_uLong nStt, sal_uLong nEnd )
+void CompareData::ShowInsert( sal_uLong nStt, sal_uLong nEnd )
{
SwPaM* pTmp = new SwPaM( static_cast<const SwCompareLine*>(GetLine( nStt ))->GetNode(), 0,
static_cast<const SwCompareLine*>(GetLine( nEnd-1 ))->GetEndNode(), 0,
@@ -1508,7 +1513,7 @@ void SwCompareData::ShowInsert( sal_uLong nStt, sal_uLong nEnd )
// #i65201#: These SwPaMs are calculated smaller than needed, see comment below
}
-void SwCompareData::ShowDelete(
+void CompareData::ShowDelete(
const CompareData& rData,
sal_uLong nStt,
sal_uLong nEnd,
@@ -1541,14 +1546,14 @@ void SwCompareData::ShowDelete(
}
else
{
- pLineNd = &rDoc.GetNodes().GetEndOfContent();
+ pLineNd = &GetEndOfContent();
nOffset = 0;
}
SwNodeIndex aInsPos( *pLineNd, nOffset );
SwNodeIndex aSavePos( aInsPos, -1 );
- static_cast<const SwCompareData&>(rData).rDoc.GetDocumentContentOperationsManager().CopyWithFlyInFly( aRg, 0, aInsPos );
+ rData.rDoc.GetDocumentContentOperationsManager().CopyWithFlyInFly( aRg, 0, aInsPos );
rDoc.getIDocumentState().SetModified();
++aSavePos;
@@ -1572,7 +1577,7 @@ void SwCompareData::ShowDelete(
}
}
-void SwCompareData::CheckForChangesInLine( const CompareData& rData,
+void CompareData::CheckForChangesInLine( const CompareData& rData,
sal_uLong& rStt, sal_uLong& rEnd,
sal_uLong& rThisStt, sal_uLong& rThisEnd )
{
@@ -1625,7 +1630,7 @@ void SwCompareData::CheckForChangesInLine( const CompareData& rData,
}
}
-void SwCompareData::SetRedlinesToDoc( bool bUseDocInfo )
+void CompareData::SetRedlinesToDoc( bool bUseDocInfo )
{
SwPaM* pTmp = pDelRing;
@@ -1673,7 +1678,7 @@ void SwCompareData::SetRedlinesToDoc( bool bUseDocInfo )
}
// #i101009#
// prevent redlines that end on structural end node
- if (& rDoc.GetNodes().GetEndOfContent() ==
+ if (& GetEndOfContent() ==
& pTmp->GetPoint()->nNode.GetNode())
{
pTmp->GetPoint()->nNode--;
@@ -1705,7 +1710,7 @@ void SwCompareData::SetRedlinesToDoc( bool bUseDocInfo )
}
// #i101009#
// prevent redlines that end on structural end node
- if (& rDoc.GetNodes().GetEndOfContent() ==
+ if (& GetEndOfContent() ==
& pTmp->GetPoint()->nNode.GetNode())
{
pTmp->GetPoint()->nNode--;
@@ -1760,6 +1765,48 @@ void SwCompareData::SetRedlinesToDoc( bool bUseDocInfo )
}
}
+typedef std::shared_ptr<CompareData> CompareDataPtr;
+typedef std::pair<CompareDataPtr, CompareDataPtr> CompareDataPtrPair;
+typedef std::vector<CompareDataPtrPair> Comparators;
+
+namespace
+{
+ Comparators buildComparators(SwDoc &rSrcDoc, SwDoc &rDestDoc)
+ {
+ Comparators aComparisons;
+ //compare main text
+ aComparisons.push_back(CompareDataPtrPair(CompareDataPtr(new CompareMainText(rSrcDoc)),
+ CompareDataPtr(new CompareMainText(rDestDoc))));
+
+ //if we have the same number of frames then try to compare within them
+ const SwFrmFmts *pSrcFrmFmts = rSrcDoc.GetSpzFrmFmts();
+ const SwFrmFmts *pDestFrmFmts = rDestDoc.GetSpzFrmFmts();
+ if (pSrcFrmFmts->size() == pDestFrmFmts->size())
+ {
+ for (size_t i = 0; i < pSrcFrmFmts->size(); ++i)
+ {
+ const SwFrmFmt& rSrcFmt = *(*pSrcFrmFmts)[i];
+ const SwFrmFmt& rDestFmt = *(*pDestFrmFmts)[i];
+ const SwNodeIndex* pSrcIdx = rSrcFmt.GetCntnt().GetCntntIdx();
+ const SwNodeIndex* pDestIdx = rDestFmt.GetCntnt().GetCntntIdx();
+ if (!pSrcIdx && !pDestIdx)
+ continue;
+ if (!pSrcIdx || !pDestIdx)
+ break;
+ const SwNode* pSrcNode = pSrcIdx->GetNode().EndOfSectionNode();
+ const SwNode* pDestNode = pDestIdx->GetNode().EndOfSectionNode();
+ if (!pSrcNode && !pDestNode)
+ continue;
+ if (!pSrcNode || !pDestNode)
+ break;
+ aComparisons.push_back(CompareDataPtrPair(CompareDataPtr(new CompareFrmFmtText(rSrcDoc, *pSrcIdx)),
+ CompareDataPtr(new CompareFrmFmtText(rDestDoc, *pDestIdx))));
+ }
+ }
+ return aComparisons;
+ }
+}
+
// Returns (the difference count?) if something is different
long SwDoc::CompareDoc( const SwDoc& rDoc )
{
@@ -1800,19 +1847,26 @@ long SwDoc::CompareDoc( const SwDoc& rDoc )
rSrcDoc.getIDocumentRedlineAccess().SetRedlineMode( nsRedlineMode_t::REDLINE_SHOW_INSERT );
getIDocumentRedlineAccess().SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_ON | nsRedlineMode_t::REDLINE_SHOW_INSERT));
- SwCompareData aD0( rSrcDoc );
- SwCompareData aD1( *this );
-
- aD1.CompareLines( aD0 );
+ Comparators aComparisons(buildComparators(rSrcDoc, *this));
- nRet = aD1.ShowDiffs( aD0 );
+ for (auto& a : aComparisons)
+ {
+ CompareData& rD0 = *a.first.get();
+ CompareData& rD1 = *a.second.get();
+ rD1.CompareLines( rD0 );
+ nRet |= rD1.ShowDiffs( rD0 );
+ }
if( nRet )
{
- getIDocumentRedlineAccess().SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_ON |
+ getIDocumentRedlineAccess().SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_ON |
nsRedlineMode_t::REDLINE_SHOW_INSERT | nsRedlineMode_t::REDLINE_SHOW_DELETE));
- aD1.SetRedlinesToDoc( !bDocWasModified );
+ for (auto& a : aComparisons)
+ {
+ CompareData& rD1 = *a.second.get();
+ rD1.SetRedlinesToDoc( !bDocWasModified );
+ }
getIDocumentState().SetModified();
}
@@ -2016,11 +2070,9 @@ long SwDoc::MergeDoc( const SwDoc& rDoc )
rSrcDoc.getIDocumentRedlineAccess().SetRedlineMode( nsRedlineMode_t::REDLINE_SHOW_DELETE );
getIDocumentRedlineAccess().SetRedlineMode( nsRedlineMode_t::REDLINE_SHOW_DELETE );
- SwCompareData aD0( rSrcDoc );
- SwCompareData aD1( *this );
-
+ CompareMainText aD0(rSrcDoc, false);
+ CompareMainText aD1(*this, false);
aD1.CompareLines( aD0 );
-
if( !aD1.HasDiffs( aD0 ) )
{
// we want to get all redlines from the SourceDoc
--
1.9.3

@ -1,25 +0,0 @@
From 08fe34b1b00fee1ee9b4332c8e4b9142af63b4a5 Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Thu, 5 Feb 2015 14:46:31 +0100
Subject: [PATCH 1/2] build libetonyek with no-strict-aliasing
Change-Id: I004133fb8a8e55cce74470078013e102d6c0514e
---
external/libetonyek/ExternalProject_libetonyek.mk | 1 +
1 file changed, 1 insertion(+)
diff --git a/external/libetonyek/ExternalProject_libetonyek.mk b/external/libetonyek/ExternalProject_libetonyek.mk
index b4b5589..6e090b1 100644
--- a/external/libetonyek/ExternalProject_libetonyek.mk
+++ b/external/libetonyek/ExternalProject_libetonyek.mk
@@ -38,6 +38,7 @@ $(call gb_ExternalProject_get_state_target,libetonyek,build) :
XML_CFLAGS="$(LIBXML_CFLAGS)" \
XML_LIBS="$(LIBXML_LIBS)" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
+ CXXFLAGS="$(CXXFLAGS) -fno-strict-aliasing" \
&& $(MAKE) \
)
--
2.1.0

@ -1,25 +0,0 @@
From 2965b3d99a59db87e65ed4c21a09e33ee5408867 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Thu, 20 Nov 2014 10:14:34 +0000
Subject: [PATCH] disable test
Change-Id: Iafc258eeb648e4f172277f7b20bf8b035e7fa52f
---
writerperfect/Module_writerperfect.mk | 1 -
1 file changed, 1 deletion(-)
diff --git a/writerperfect/Module_writerperfect.mk b/writerperfect/Module_writerperfect.mk
index 9c30697..81f6887 100644
--- a/writerperfect/Module_writerperfect.mk
+++ b/writerperfect/Module_writerperfect.mk
@@ -33,7 +33,6 @@ $(eval $(call gb_Module_add_check_targets,writerperfect,\
$(eval $(call gb_Module_add_slowcheck_targets,writerperfect,\
CppunitTest_writerperfect_calc \
- CppunitTest_writerperfect_draw \
CppunitTest_writerperfect_impress \
CppunitTest_writerperfect_writer \
StaticLibrary_writerperfect_importtestbase \
--
1.9.3

@ -1,31 +0,0 @@
From 642b908049decaa2da5064a9b09afbf2589bd881 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Fri, 20 Mar 2015 16:48:57 +0000
Subject: [PATCH] gdk-pixbuf-xlib-2.0->gdk-pixbuf-2.0
(cherry picked from commit 7fff01817f61a2eb53a5da7248163630a7fb1555)
Conflicts:
configure.ac
Change-Id: Ib58578fd9e093d912294d861094e19151a097534
---
configure.ac | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/configure.ac b/configure.ac
index fd9a74b..ac7e78e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -10056,7 +10056,7 @@ ENABLE_SYSTRAY_GTK=""
if test "$test_gtk" = "yes"; then
if test "$ENABLE_GTK" = "TRUE"; then
- PKG_CHECK_MODULES(GTK, gtk+-2.0 >= 2.4 gdk-pixbuf-xlib-2.0 >= 2.2 ,,AC_MSG_ERROR([requirements to build the gtk-plugin not met. Use --disable-gtk or install the missing packages]))
+ PKG_CHECK_MODULES(GTK, gtk+-2.0 >= 2.4 gdk-pixbuf-2.0 >= 2.2 ,,AC_MSG_ERROR([requirements to build the gtk-plugin not met. Use --disable-gtk or install the missing packages]))
GTK_CFLAGS=$(printf '%s' "$GTK_CFLAGS" | sed -e "s/-I/${ISYSTEM?}/g")
PKG_CHECK_MODULES(GTHREAD, gthread-2.0,,AC_MSG_ERROR([requirements to build the gtk-plugin not met. Use --disable-gtk or install the missing packages]))
BUILD_TYPE="$BUILD_TYPE GTK"
--
1.9.3

@ -1,100 +0,0 @@
From 27e0fee7da99f3df722668d132bc034bef421514 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Fri, 27 Mar 2015 15:28:28 +0000
Subject: [PATCH] gnome#745909 grab/ungrab keyboard for menus
Change-Id: Id0593e1c9af79084ae798f26a0be37c57d254227
---
vcl/inc/unx/gtk/gtkframe.hxx | 3 ++-
vcl/unx/gtk/window/gtksalframe.cxx | 39 ++++++++++++++++++++++++++++++++++++--
2 files changed, 39 insertions(+), 3 deletions(-)
diff --git a/vcl/inc/unx/gtk/gtkframe.hxx b/vcl/inc/unx/gtk/gtkframe.hxx
index d514411..2eb0634 100644
--- a/vcl/inc/unx/gtk/gtkframe.hxx
+++ b/vcl/inc/unx/gtk/gtkframe.hxx
@@ -328,7 +328,8 @@ public:
// and false else; if true was returned the event should
// be swallowed
bool Dispatch( const XEvent* pEvent );
- void grabPointer( bool bGrab, bool bOwnerEvents = false );
+ void grabPointer(bool bGrab, bool bOwnerEvents = false);
+ void grabKeyboard(bool bGrab);
GtkSalDisplay* getDisplay();
GdkDisplay* getGdkDisplay();
diff --git a/vcl/unx/gtk/window/gtksalframe.cxx b/vcl/unx/gtk/window/gtksalframe.cxx
index aa94c26..1b8bdc5 100644
--- a/vcl/unx/gtk/window/gtksalframe.cxx
+++ b/vcl/unx/gtk/window/gtksalframe.cxx
@@ -1864,7 +1864,13 @@ void GtkSalFrame::Show( bool bVisible, bool bNoActivate )
{
m_nFloats++;
if( ! getDisplay()->GetCaptureFrame() && m_nFloats == 1 )
- grabPointer( true, true );
+ {
+ grabPointer(true, true);
+ GtkSalFrame *pKeyboardFrame = this;
+ while (pKeyboardFrame->m_pParent)
+ pKeyboardFrame = pKeyboardFrame->m_pParent;
+ pKeyboardFrame->grabKeyboard(true);
+ }
// #i44068# reset parent's IM context
if( m_pParent )
m_pParent->EndExtTextInput(0);
@@ -1878,7 +1884,13 @@ void GtkSalFrame::Show( bool bVisible, bool bNoActivate )
{
m_nFloats--;
if( ! getDisplay()->GetCaptureFrame() && m_nFloats == 0)
- grabPointer( false );
+ {
+ GtkSalFrame *pKeyboardFrame = this;
+ while (pKeyboardFrame->m_pParent)
+ pKeyboardFrame = pKeyboardFrame->m_pParent;
+ pKeyboardFrame->grabKeyboard(false);
+ grabPointer(false);
+ }
}
gtk_widget_hide( m_pWindow );
if( m_pIMHandler )
@@ -2762,7 +2774,9 @@ void GtkSalFrame::grabPointer( bool bGrab, bool bOwnerEvents )
{
// Two GdkDisplays may be open
if( !pEnv || !*pEnv )
+ {
gdk_display_pointer_ungrab( getGdkDisplay(), GDK_CURRENT_TIME);
+ }
}
}
#else
@@ -2771,6 +2785,27 @@ void GtkSalFrame::grabPointer( bool bGrab, bool bOwnerEvents )
#endif
}
+void GtkSalFrame::grabKeyboard( bool bGrab )
+{
+#if !GTK_CHECK_VERSION(3,0,0)
+ if( m_pWindow )
+ {
+ if( bGrab )
+ {
+ gdk_keyboard_grab(widget_get_window(m_pWindow), true,
+ GDK_CURRENT_TIME);
+ }
+ else
+ {
+ gdk_keyboard_ungrab(GDK_CURRENT_TIME);
+ }
+ }
+#else
+ (void)bGrab;
+ //FIXME: No GrabKeyboard implementation for gtk3 ...
+#endif
+}
+
void GtkSalFrame::CaptureMouse( bool bCapture )
{
getDisplay()->CaptureMouse( bCapture ? this : NULL );
--
1.9.3

@ -1,34 +0,0 @@
From 7a66dbe982623be620ad6ac426fe689a434e5f51 Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Tue, 12 May 2015 10:37:53 +0200
Subject: [PATCH] java dir for powepc64 and powepc64le can differ
E.g., RHEL >= 7.1 uses ppc64le for reasons listed in
https://bugs.openjdk.java.net/browse/JDK-8073139 .
Change-Id: I982e65cdf99999e8a5ed23cf444ccb2aee764c4c
---
configure.ac | 5 ++++-
1 file changed, 4 insertions(+), 1 deletion(-)
diff --git a/configure.ac b/configure.ac
index 26071dc..55157a9 100644
--- a/configure.ac
+++ b/configure.ac
@@ -6997,9 +6997,12 @@ then
powerpc)
my_java_arch=ppc
;;
- powerpc64*)
+ powerpc64)
my_java_arch=ppc64
;;
+ powerpc64le)
+ AS_IF([test -d "$JAVA_HOME/jre/lib/ppc64le"], [my_java_arch=ppc64le], [my_java_arch=ppc64])
+ ;;
x86_64)
my_java_arch=amd64
;;
--
2.4.0

@ -1,87 +0,0 @@
From b5ce50d1d07394f6b59b028373120369c83d5d66 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Tue, 7 Apr 2015 09:56:43 +0100
Subject: [PATCH] negative after-text indents ignored by msword for apos
Change-Id: I33e178f23bc4b1372c4c329954b301ae68902154
---
sw/source/filter/ww8/ww8graf.cxx | 3 +++
sw/source/filter/ww8/ww8par.hxx | 2 ++
sw/source/filter/ww8/ww8par6.cxx | 26 ++++++++++++++++++++++++++
3 files changed, 31 insertions(+)
diff --git a/sw/source/filter/ww8/ww8graf.cxx b/sw/source/filter/ww8/ww8graf.cxx
index 456ce25..3a11d1e 100644
--- a/sw/source/filter/ww8/ww8graf.cxx
+++ b/sw/source/filter/ww8/ww8graf.cxx
@@ -2905,7 +2905,10 @@ SwFlyFrmFmt* SwWW8ImplReader::ConvertDrawTextToFly(SdrObject* &rpObject,
MoveOutsideFly(pRetFrmFmt, aSave.GetStartPos(),!bJoined);
aSave.Restore( this );
+
+ StripNegativeAfterIndent(pRetFrmFmt);
}
+
}
return pRetFrmFmt;
}
diff --git a/sw/source/filter/ww8/ww8par.hxx b/sw/source/filter/ww8/ww8par.hxx
index a7fdff5..0a34059 100644
--- a/sw/source/filter/ww8/ww8par.hxx
+++ b/sw/source/filter/ww8/ww8par.hxx
@@ -1488,6 +1488,7 @@ private:
bool IsDropCap();
bool IsListOrDropcap() { return (!pAktItemSet || bDropCap); };
+ //Apo == Absolutely Positioned Object, MSWord's old-style frames
WW8FlyPara *ConstructApo(const ApoTestResults &rApo,
const WW8_TablePos *pTabPos);
bool StartApo(const ApoTestResults &rApo, const WW8_TablePos *pTabPos, SvxULSpaceItem* pULSpaceItem = 0);
@@ -1495,6 +1496,7 @@ private:
bool TestSameApo(const ApoTestResults &rApo, const WW8_TablePos *pTabPos);
ApoTestResults TestApo(int nCellLevel, bool bTableRowEnd,
const WW8_TablePos *pTabPos);
+ void StripNegativeAfterIndent(SwFrmFmt *pFlyFmt) const;
void EndSpecial();
bool ProcessSpecial(bool &rbReSync, WW8_CP nStartCp);
diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 418e130..b63e639 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -2430,6 +2430,32 @@ bool SwWW8ImplReader::JoinNode(SwPaM &rPam, bool bStealAttr)
return bRet;
}
+//In auto-width word frames negative after-indent values are ignored
+void SwWW8ImplReader::StripNegativeAfterIndent(SwFrmFmt *pFlyFmt) const
+{
+ const SwNodeIndex* pSttNd = pFlyFmt->GetCntnt().GetCntntIdx();
+ if (!pSttNd)
+ return;
+
+ SwNodeIndex aIdx(*pSttNd, 1);
+ SwNodeIndex aEnd(*pSttNd->GetNode().EndOfSectionNode());
+ while (aIdx < aEnd)
+ {
+ SwTxtNode *pNd = aIdx.GetNode().GetTxtNode();
+ if (pNd)
+ {
+ const SvxLRSpaceItem& rLR = ItemGet<SvxLRSpaceItem>(*pNd, RES_LR_SPACE);
+ if (rLR.GetRight() < 0)
+ {
+ SvxLRSpaceItem aLR(rLR);
+ aLR.SetRight(0);
+ pNd->SetAttr(aLR);
+ }
+ }
+ ++aIdx;
+ }
+}
+
void SwWW8ImplReader::StopApo()
{
OSL_ENSURE(pWFlyPara, "no pWFlyPara to close");
--
1.9.3

@ -1,117 +0,0 @@
From fe7fa0baffe2cbc282eb3108be53762b919396c1 Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Mon, 27 Apr 2015 11:37:07 -0400
Subject: [PATCH] ppc64: do not use asm block to retrieve args
Some versions of gcc clobber one of the registries that are used to pass
arguments in the function's prologue, like:
Dump of assembler code for function (anonymous namespace)::privateSnippetExecutor():
510 {
0x00003fffaffe8454 <+0>: mflr r0
0x00003fffaffe8458 <+4>: std r0,16(r1)
0x00003fffaffe845c <+8>: std r29,-24(r1)
0x00003fffaffe8460 <+12>: std r30,-16(r1)
0x00003fffaffe8464 <+16>: std r31,-8(r1)
0x00003fffaffe8468 <+20>: stdu r1,-352(r1)
0x00003fffaffe846c <+24>: mr r31,r1
=> 0x00003fffaffe8470 <+28>: ld r8,-28688(r13)
0x00003fffaffe8474 <+32>: std r8,312(r31)
0x00003fffaffe8478 <+36>: li r8,0
Reading the registries through variables makes gcc aware that they are
used, so it does not touch them. It has got no negative effect on
performance, as it produces the same object code as the current asm
block.
Change-Id: I3b99b0aa9944f9f33de9a42508e9d4dd23cec5e0
---
.../cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx | 65 ++++++++++------------
1 file changed, 29 insertions(+), 36 deletions(-)
diff --git a/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx b/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx
index 0748d24..6b58246 100644
--- a/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx
+++ b/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx
@@ -510,49 +510,42 @@ static typelib_TypeClass cpp_mediate(
extern "C" void privateSnippetExecutor( ... )
{
sal_uInt64 gpreg[ppc64::MAX_GPR_REGS];
+
+ register long r3 asm("r3"); gpreg[0] = r3;
+ register long r4 asm("r4"); gpreg[1] = r4;
+ register long r5 asm("r5"); gpreg[2] = r5;
+ register long r6 asm("r6"); gpreg[3] = r6;
+ register long r7 asm("r7"); gpreg[4] = r7;
+ register long r8 asm("r8"); gpreg[5] = r8;
+ register long r9 asm("r9"); gpreg[6] = r9;
+ register long r10 asm("r10"); gpreg[7] = r10;
+
double fpreg[ppc64::MAX_SSE_REGS];
__asm__ __volatile__ (
- "std 3, 0(%0)\t\n"
- "std 4, 8(%0)\t\n"
- "std 5, 16(%0)\t\n"
- "std 6, 24(%0)\t\n"
- "std 7, 32(%0)\t\n"
- "std 8, 40(%0)\t\n"
- "std 9, 48(%0)\t\n"
- "std 10, 56(%0)\t\n"
- "stfd 1, 0(%1)\t\n"
- "stfd 2, 8(%1)\t\n"
- "stfd 3, 16(%1)\t\n"
- "stfd 4, 24(%1)\t\n"
- "stfd 5, 32(%1)\t\n"
- "stfd 6, 40(%1)\t\n"
- "stfd 7, 48(%1)\t\n"
- "stfd 8, 56(%1)\t\n"
- "stfd 9, 64(%1)\t\n"
- "stfd 10, 72(%1)\t\n"
- "stfd 11, 80(%1)\t\n"
- "stfd 12, 88(%1)\t\n"
- "stfd 13, 96(%1)\t\n"
- : : "r" (gpreg), "r" (fpreg)
- : "r0", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11",
- "fr1", "fr2", "fr3", "fr4", "fr5", "fr6", "fr7", "fr8", "fr9",
+ "stfd 1, 0(%0)\t\n"
+ "stfd 2, 8(%0)\t\n"
+ "stfd 3, 16(%0)\t\n"
+ "stfd 4, 24(%0)\t\n"
+ "stfd 5, 32(%0)\t\n"
+ "stfd 6, 40(%0)\t\n"
+ "stfd 7, 48(%0)\t\n"
+ "stfd 8, 56(%0)\t\n"
+ "stfd 9, 64(%0)\t\n"
+ "stfd 10, 72(%0)\t\n"
+ "stfd 11, 80(%0)\t\n"
+ "stfd 12, 88(%0)\t\n"
+ "stfd 13, 96(%0)\t\n"
+ : : "r" (fpreg)
+ : "fr1", "fr2", "fr3", "fr4", "fr5", "fr6", "fr7", "fr8", "fr9",
"fr10", "fr11", "fr12", "fr13"
);
- volatile long nOffsetAndIndex;
-
- //mr %r3, %r11 # move into arg1 the 64bit value passed from OOo
- __asm__ __volatile__ (
- "mr %0, 11\n\t"
- : "=r" (nOffsetAndIndex) : );
-
- volatile long sp;
+ register long r11 asm("r11");
+ const long nOffsetAndIndex = r11;
- //stack pointer
- __asm__ __volatile__ (
- "mr %0, 1\n\t"
- : "=r" (sp) : );
+ register long r1 asm("r1");
+ const long sp = r1;
#if defined(_CALL_ELF) && _CALL_ELF == 2
volatile long nRegReturn[2];
--
2.3.5

@ -1,148 +0,0 @@
From 7e787af122ebcef29b284e8c46d84a12c0625cd8 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Caol=C3=A1n=20McNamara?= <caolanm@redhat.com>
Date: Mon, 12 Jan 2015 15:45:19 +0000
Subject: [PATCH] radio check top/center/bottom alignment for table cells
Change-Id: I30b51510ac5fbfb3c1dd09e0f86a246a8b516f1e
(cherry picked from commit 2aa40ecebb2cb1e5d2cf85d7ada70b5e541bad67)
---
sw/source/ui/app/mn.src | 3 +++
sw/uiconfig/sglobal/menubar/menubar.xml | 6 +++---
sw/uiconfig/sweb/menubar/menubar.xml | 6 +++---
sw/uiconfig/swform/menubar/menubar.xml | 6 +++---
sw/uiconfig/swreport/menubar/menubar.xml | 6 +++---
sw/uiconfig/swriter/menubar/menubar.xml | 6 +++---
sw/uiconfig/swxform/menubar/menubar.xml | 6 +++---
7 files changed, 21 insertions(+), 18 deletions(-)
diff --git a/sw/source/ui/app/mn.src b/sw/source/ui/app/mn.src
index 4fa9b14..4bb40ac 100644
--- a/sw/source/ui/app/mn.src
+++ b/sw/source/ui/app/mn.src
@@ -397,18 +397,21 @@
SEPARATOR ; \
MenuItem\
{\
+ RadioCheck = TRUE ; \
Identifier = SID_TABLE_VERT_NONE ; \
HelpId = CMD_SID_TABLE_VERT_NONE ; \
Text [ en-US ] = "~Top" ; \
};\
MenuItem\
{\
+ RadioCheck = TRUE ; \
Identifier = SID_TABLE_VERT_CENTER ; \
HelpId = CMD_SID_TABLE_VERT_CENTER ; \
Text [ en-US ] = "C~enter" ; \
};\
MenuItem\
{\
+ RadioCheck = TRUE ; \
Identifier = SID_TABLE_VERT_BOTTOM ; \
HelpId = CMD_SID_TABLE_VERT_BOTTOM ; \
Text [ en-US ] = "~Bottom" ; \
diff --git a/sw/uiconfig/sglobal/menubar/menubar.xml b/sw/uiconfig/sglobal/menubar/menubar.xml
index d5736a5..6f09ae8 100644
--- a/sw/uiconfig/sglobal/menubar/menubar.xml
+++ b/sw/uiconfig/sglobal/menubar/menubar.xml
@@ -304,9 +304,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
diff --git a/sw/uiconfig/sweb/menubar/menubar.xml b/sw/uiconfig/sweb/menubar/menubar.xml
index ee78c24..87115d4 100644
--- a/sw/uiconfig/sweb/menubar/menubar.xml
+++ b/sw/uiconfig/sweb/menubar/menubar.xml
@@ -248,9 +248,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
diff --git a/sw/uiconfig/swform/menubar/menubar.xml b/sw/uiconfig/swform/menubar/menubar.xml
index ddf914f..7305ceb 100644
--- a/sw/uiconfig/swform/menubar/menubar.xml
+++ b/sw/uiconfig/swform/menubar/menubar.xml
@@ -303,9 +303,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
diff --git a/sw/uiconfig/swreport/menubar/menubar.xml b/sw/uiconfig/swreport/menubar/menubar.xml
index fab0914..a41c3c2 100644
--- a/sw/uiconfig/swreport/menubar/menubar.xml
+++ b/sw/uiconfig/swreport/menubar/menubar.xml
@@ -304,9 +304,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
diff --git a/sw/uiconfig/swriter/menubar/menubar.xml b/sw/uiconfig/swriter/menubar/menubar.xml
index b26b980..f5b3fa9 100644
--- a/sw/uiconfig/swriter/menubar/menubar.xml
+++ b/sw/uiconfig/swriter/menubar/menubar.xml
@@ -312,9 +312,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
diff --git a/sw/uiconfig/swxform/menubar/menubar.xml b/sw/uiconfig/swxform/menubar/menubar.xml
index ec9f631..4c08ef2 100644
--- a/sw/uiconfig/swxform/menubar/menubar.xml
+++ b/sw/uiconfig/swxform/menubar/menubar.xml
@@ -305,9 +305,9 @@
<menu:menuitem menu:id=".uno:CommonAlignRight" menu:style="radio"/>
<menu:menuitem menu:id=".uno:CommonAlignJustified" menu:style="radio"/>
<menu:menuseparator/>
- <menu:menuitem menu:id=".uno:CommonAlignTop"/>
- <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter"/>
- <menu:menuitem menu:id=".uno:CommonAlignBottom"/>
+ <menu:menuitem menu:id=".uno:CommonAlignTop" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignVerticalCenter" menu:style="radio"/>
+ <menu:menuitem menu:id=".uno:CommonAlignBottom" menu:style="radio"/>
</menu:menupopup>
</menu:menu>
<menu:menu menu:id=".uno:ArrangeMenu">
--
1.9.3

@ -1,79 +0,0 @@
From 51e0d789c344547956764c3b5f0ef5a304f4e0aa Mon Sep 17 00:00:00 2001
From: Stephan Bergmann <sbergman@redhat.com>
Date: Mon, 13 Apr 2015 18:27:33 +0200
Subject: [PATCH] rhbz#1134285: Access dav, davs URLs via GVFS
...so that LO shares the credentials with Nautilus once the connection has been
set up in Nautilus.
The reason the (non-standard) dav, davs URLs used by GNOME's old GnomeVFS and
successor GVFS/GIO were handled via LO's webdav UCP rather than the GNOME-
specific gnomevfs resp. gio UCP since b07a5fcc600ad564315d36fbd18495184fdf69cf
"INTEGRATION: CWS tkr10: i84676 neon and gnome-vfs2" is discussed at
<https://bz.apache.org/ooo/show_bug.cgi?id=84676> "mixing neon and the hidden
embedded contents old [sic] another neon inside libhttp.so of gnome-vfs2 is
unreliable" and only pertains to the legacy gnomevfs UCP, not the new gio one.
So keep handling dav, davs URLs via LO's internal webdav UCP under legacy
--enable-gnome-vfs, but handle them via the GNOME-specific gio UCP under the
default --enable-gio.
Change-Id: Ib132168701a7ae0a7dcabdead6a299eda0cd4594
---
officecfg/Configuration_officecfg.mk | 1 +
officecfg/registry/data/org/openoffice/ucb/Configuration.xcu | 6 ++++--
postprocess/CustomTarget_registry.mk | 3 +++
3 files changed, 8 insertions(+), 2 deletions(-)
diff --git a/officecfg/Configuration_officecfg.mk b/officecfg/Configuration_officecfg.mk
index 7e2af03..af992b9 100644
--- a/officecfg/Configuration_officecfg.mk
+++ b/officecfg/Configuration_officecfg.mk
@@ -121,6 +121,7 @@ $(eval $(call gb_Configuration_add_spool_modules,registry,officecfg/registry/dat
org/openoffice/TypeDetection/UISort-math.xcu \
org/openoffice/ucb/Configuration-gio.xcu \
org/openoffice/ucb/Configuration-neon.xcu \
+ org/openoffice/ucb/Configuration-neon_gnomevfs.xcu \
org/openoffice/ucb/Configuration-win.xcu \
))
diff --git a/officecfg/registry/data/org/openoffice/ucb/Configuration.xcu b/officecfg/registry/data/org/openoffice/ucb/Configuration.xcu
index e9704d3..9cb2a1a 100644
--- a/officecfg/registry/data/org/openoffice/ucb/Configuration.xcu
+++ b/officecfg/registry/data/org/openoffice/ucb/Configuration.xcu
@@ -89,7 +89,8 @@
<value/>
</prop>
</node>
- <node oor:name="Provider7" oor:op="replace" install:module="neon">
+ <node oor:name="Provider7" oor:op="replace"
+ install:module="neon_gnomevfs">
<prop oor:name="ServiceName">
<value>com.sun.star.ucb.WebDAVContentProvider</value>
</prop>
@@ -155,7 +156,8 @@
<value/>
</prop>
</node>
- <node oor:name="Provider13" oor:op="replace" install:module="neon">
+ <node oor:name="Provider13" oor:op="replace"
+ install:module="neon_gnomevfs">
<prop oor:name="ServiceName">
<value>com.sun.star.ucb.WebDAVContentProvider</value>
</prop>
diff --git a/postprocess/CustomTarget_registry.mk b/postprocess/CustomTarget_registry.mk
index a568832..e12640f 100644
--- a/postprocess/CustomTarget_registry.mk
+++ b/postprocess/CustomTarget_registry.mk
@@ -328,6 +328,9 @@ postprocess_DRIVERS += ado
endif
ifneq ($(WITH_WEBDAV),)
postprocess_FILES_main += $(postprocess_MOD)/org/openoffice/ucb/Configuration-neon.xcu
+ifeq ($(ENABLE_GNOMEVFS),TRUE)
+postprocess_FILES_main += $(postprocess_MOD)/org/openoffice/ucb/Configuration-neon_gnomevfs.xcu
+endif
endif
ifeq ($(ENABLE_EVOAB2),TRUE)
postprocess_FILES_main += $(call gb_XcuModuleTarget_get_target,connectivity/registry/evoab2)/org/openoffice/Office/DataAccess/Drivers-evoab2.xcu
--
2.1.0

@ -1,77 +0,0 @@
From 97d4c1a8100c63091401736c93d6bbbb371d5b37 Mon Sep 17 00:00:00 2001
From: Stephan Bergmann <sbergman@redhat.com>
Date: Fri, 10 Apr 2015 15:06:53 +0200
Subject: [PATCH] rhbz#1197614: Fix calculation of m_bHasActive when removing
active element
Assume m_vEntries.size() == 2; assume first element (nPos == 0) is m_bActive,
gets removed, so m_nActive would have stayed at 0 and m_bHasActive at true; then
assume second element (again nPos == 0, due to the removed element) is m_bNew,
so nPos <= m_nActive is true and m_nActive gets updated to 1 (and m_bHasActive
remains true); then selectEntry(nNewPos) (nNewPos == 0) would have tried to
reset m_vEntries[1]->m_bActive but now m_vEntries.size() == 1.
Change-Id: I31d3bbe97ca99f880aa99bdea015f7c0457f8331
---
desktop/source/deployment/gui/dp_gui_extlistbox.cxx | 21 ++++++++++++++-------
1 file changed, 14 insertions(+), 7 deletions(-)
diff --git a/desktop/source/deployment/gui/dp_gui_extlistbox.cxx b/desktop/source/deployment/gui/dp_gui_extlistbox.cxx
index 260100f..b9500a1 100644
--- a/desktop/source/deployment/gui/dp_gui_extlistbox.cxx
+++ b/desktop/source/deployment/gui/dp_gui_extlistbox.cxx
@@ -1035,7 +1035,6 @@ long ExtensionBox_Impl::addEntry( const uno::Reference< deployment::XPackage > &
//access to m_nActive must be guarded
if ( !m_bInCheckMode && m_bHasActive && ( m_nActive >= nPos ) )
m_nActive += 1;
-
guard.clear();
if ( IsReallyVisible() )
@@ -1172,6 +1171,7 @@ void ExtensionBox_Impl::prepareChecking()
void ExtensionBox_Impl::checkEntries()
{
long nNewPos = -1;
+ long nChangedActivePos = -1;
long nPos = 0;
bool bNeedsUpdate = false;
@@ -1195,15 +1195,19 @@ void ExtensionBox_Impl::checkEntries()
}
else
{ // remove entry from list
+ if (nPos < nNewPos) {
+ --nNewPos;
+ }
+ if (nPos < nChangedActivePos) {
+ --nChangedActivePos;
+ }
if ( nPos < m_nActive )
m_nActive -= 1;
- else if ( ( nPos == m_nActive ) && ( nPos == (long) m_vEntries.size() - 1 ) )
+ else if ( nPos == m_nActive )
{
- m_nActive -= 1;
- if (m_nActive == -1)
- {
- m_bHasActive = false;
- }
+ nChangedActivePos = nPos;
+ m_nActive = -1;
+ m_bHasActive = false;
}
m_vRemovedEntries.push_back( *iIndex );
m_vEntries.erase( iIndex );
@@ -1219,6 +1223,9 @@ void ExtensionBox_Impl::checkEntries()
if ( nNewPos != - 1)
selectEntry( nNewPos );
+ else if (nChangedActivePos != -1) {
+ selectEntry(nChangedActivePos);
+ }
if ( bNeedsUpdate )
{
--
2.1.0

@ -1,85 +0,0 @@
From d8eee8e4d1a303044bf34b28c2e95bd6da23fd79 Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Tue, 12 May 2015 12:10:16 +0200
Subject: [PATCH] java dir for powepc64 and powepc64le can differ
E.g., RHEL >= 7.1 uses ppc64le for reasons listed in
https://bugs.openjdk.java.net/browse/JDK-8073139 .
This is a follow-up to commit 7a66dbe982623be620ad6ac426fe689a434e5f51.
Change-Id: I685f76d51e9775788a7fb225c6a5e2309a45ceb7
---
config_host/config_java.h.in | 6 ++++++
configure.ac | 3 +++
jvmfwk/inc/vendorbase.hxx | 6 +++++-
3 files changed, 14 insertions(+), 1 deletion(-)
create mode 100644 config_host/config_java.h.in
diff --git a/config_host/config_java.h.in b/config_host/config_java.h.in
new file mode 100644
index 0000000..8b23de9
--- /dev/null
+++ b/config_host/config_java.h.in
@@ -0,0 +1,6 @@
+#ifndef CONFIG_JAVA_H
+#define CONFIG_JAVA_H
+
+#undef JAVA_ARCH
+
+#endif
diff --git a/configure.ac b/configure.ac
index 55157a9..5414754 100644
--- a/configure.ac
+++ b/configure.ac
@@ -7002,6 +7002,7 @@ then
;;
powerpc64le)
AS_IF([test -d "$JAVA_HOME/jre/lib/ppc64le"], [my_java_arch=ppc64le], [my_java_arch=ppc64])
+ JAVA_ARCH=$my_java_arch
;;
x86_64)
my_java_arch=amd64
@@ -7011,6 +7012,7 @@ then
;;
esac
JAWTLIB="-L$JAVA_HOME/jre/lib/$my_java_arch -ljawt"
+ AS_IF([test "$JAVA_ARCH" != ""], [AC_DEFINE_UNQUOTED([JAVA_ARCH], ["$JAVA_ARCH"])])
fi
AC_MSG_RESULT([$JAWTLIB])
fi
@@ -12988,6 +12990,7 @@ AC_CONFIG_HEADERS([config_host/config_folders.h])
AC_CONFIG_HEADERS([config_host/config_gcc.h])
AC_CONFIG_HEADERS([config_host/config_global.h])
AC_CONFIG_HEADERS([config_host/config_graphite.h])
+AC_CONFIG_HEADERS([config_host/config_java.h])
AC_CONFIG_HEADERS([config_host/config_lgpl.h])
AC_CONFIG_HEADERS([config_host/config_liblangtag.h])
AC_CONFIG_HEADERS([config_host/config_locales.h])
diff --git a/jvmfwk/inc/vendorbase.hxx b/jvmfwk/inc/vendorbase.hxx
index 2ecd01f..a01db56 100644
--- a/jvmfwk/inc/vendorbase.hxx
+++ b/jvmfwk/inc/vendorbase.hxx
@@ -20,6 +20,8 @@
#ifndef INCLUDED_JVMFWK_PLUGINS_SUNMAJOR_PLUGINLIB_VENDORBASE_HXX
#define INCLUDED_JVMFWK_PLUGINS_SUNMAJOR_PLUGINLIB_VENDORBASE_HXX
+#include "config_java.h"
+
#include "rtl/ustring.hxx"
#include "rtl/ref.hxx"
#include "osl/endian.h"
@@ -31,7 +33,9 @@ namespace jfw_plugin
//Used by subclasses of VendorBase to build paths to Java runtime
-#if defined(__sparcv9)
+#if defined(JAVA_ARCH)
+#define JFW_PLUGIN_ARCH JAVA_ARCH
+#elif defined(__sparcv9)
#define JFW_PLUGIN_ARCH "sparcv9"
#elif defined SPARC
#define JFW_PLUGIN_ARCH "sparc"
--
2.4.0

@ -1,54 +0,0 @@
From d156d513869d1e0634e981c85860c3a08b18d093 Mon Sep 17 00:00:00 2001
From: David Tardon <dtardon@redhat.com>
Date: Thu, 5 Feb 2015 15:46:58 +0100
Subject: [PATCH 2/2] propagate user-set CFLAGS to build
Change-Id: I9d72270ddd8698b776b80d4cca0a23f2ebda066a
---
external/redland/ExternalProject_raptor.mk | 2 +-
external/redland/ExternalProject_rasqal.mk | 2 +-
external/redland/ExternalProject_redland.mk | 2 +-
3 files changed, 3 insertions(+), 3 deletions(-)
diff --git a/external/redland/ExternalProject_raptor.mk b/external/redland/ExternalProject_raptor.mk
index 70d6fe7..8f2a6d5 100644
--- a/external/redland/ExternalProject_raptor.mk
+++ b/external/redland/ExternalProject_raptor.mk
@@ -35,7 +35,7 @@ else
$(call gb_ExternalProject_get_state_target,raptor,build):
$(call gb_ExternalProject_run,build,\
$(if $(filter IOS,$(OS)),LIBS="-liconv") \
- CFLAGS="$(if $(debug),-g,-O) $(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden) \
+ CFLAGS="$(CFLAGS) $(if $(debug),-g,-O) $(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden) \
$(if $(filter GCCLINUXPOWERPC64,$(COM)$(OS)$(CPUNAME)),-mminimal-toc)" \
LDFLAGS=" \
$(if $(filter LINUX FREEBSD,$(OS)),-Wl$(COMMA)-z$(COMMA)origin -Wl$(COMMA)-rpath$(COMMA)\\"\$$\$$ORIGIN:'\'\$$\$$ORIGIN/../ure-link/lib") \
diff --git a/external/redland/ExternalProject_rasqal.mk b/external/redland/ExternalProject_rasqal.mk
index 6b695de..1f373ce 100644
--- a/external/redland/ExternalProject_rasqal.mk
+++ b/external/redland/ExternalProject_rasqal.mk
@@ -41,7 +41,7 @@ $(call gb_ExternalProject_get_state_target,rasqal,build):
else
$(call gb_ExternalProject_get_state_target,rasqal,build):
$(call gb_ExternalProject_run,build,\
- CFLAGS="$(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden)" \
+ CFLAGS="$(CFLAGS) $(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden)" \
LDFLAGS=" \
$(if $(filter LINUX FREEBSD,$(OS)),-Wl$(COMMA)-z$(COMMA)origin -Wl$(COMMA)-rpath$(COMMA)\\"\$$\$$ORIGIN:'\'\$$\$$ORIGIN/../ure-link/lib") \
$(if $(SYSBASE),$(if $(filter LINUX SOLARIS,$(OS)),-L$(SYSBASE)/lib -L$(SYSBASE)/usr/lib -lpthread -ldl))" \
diff --git a/external/redland/ExternalProject_redland.mk b/external/redland/ExternalProject_redland.mk
index 9b96c9c..872384b 100644
--- a/external/redland/ExternalProject_redland.mk
+++ b/external/redland/ExternalProject_redland.mk
@@ -44,7 +44,7 @@ $(call gb_ExternalProject_get_state_target,redland,build):
else
$(call gb_ExternalProject_get_state_target,redland,build):
$(call gb_ExternalProject_run,build,\
- CFLAGS="$(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden)" \
+ CFLAGS="$(CFLAGS) $(if $(filter TRUE,$(DISABLE_DYNLOADING)),-fvisibility=hidden)" \
LDFLAGS=" \
$(if $(filter LINUX FREEBSD,$(OS)),-Wl$(COMMA)-z$(COMMA)origin -Wl$(COMMA)-rpath$(COMMA)\\"\$$\$$ORIGIN:'\'\$$\$$ORIGIN/../ure-link/lib") \
$(if $(SYSBASE),$(if $(filter LINUX SOLARIS,$(OS)),-L$(SYSBASE)/lib -L$(SYSBASE)/usr/lib -lpthread -ldl))" \
diff --git a/sdext/source/presenter/PresenterController.cxx b/sdext/source/presenter/PresenterController.cxx
index 6c64bd7..e416a73 100644
--- a/sdext/source/presenter/PresenterController.cxx
+++ b/sdext/source/presenter/PresenterController.cxx
@@ -1005,7 +1005,7 @@ void PresenterController::HandleNumericKeyPress (
case awt::KeyModifier::MOD1:
// Ctrl-1, Ctrl-2, and Ctrl-3 are used to switch between views
// (slide view, notes view, normal)
mnPendingSlideNumber = -1;
if (mpWindowManager.get() == NULL)
return;
@@ -1020,6 +1020,9 @@ void PresenterController::HandleNumericKeyPress (
case 3:
mpWindowManager->SetViewMode(PresenterWindowManager::VM_SlideOverview);
break;
+ case 4:
+ SwitchMonitors();
+ break;
default:
// Ignore unsupported key.
break;
@@ -1005,7 +1005,7 @@ void PresenterController::HandleNumericKeyPress (
case awt::KeyModifier::MOD1:
// Ctrl-1, Ctrl-2, and Ctrl-3 are used to switch between views
- // (slide view, notes view, normal)
+ // (slide view, notes view, normal). Ctrl-4 switches monitors
mnPendingSlideNumber = -1;
if (mpWindowManager.get() == NULL)
--
2.1.0

@ -3,7 +3,8 @@
# Should contain .alphaX / .betaX, if this is pre-release (actually
# pre-RC) version. The pre-release string is part of tarball file names,
# so we need a way to define it easily at one place.
%define libo_prerelease .alpha1
%define libo__prerelease beta1
%define libo_prerelease .%{?libo__prerelease}
# rhbz#715152 state vendor
%if 0%{?rhel}
%define vendoroption --with-vendor="Red Hat, Inc."
@ -51,7 +52,7 @@ Summary: Free Software Productivity Suite
Name: libreoffice
Epoch: 1
Version: %{libo_version}.0
Release: 2%{?libo_prerelease}%{?dist}
Release: 3%{?libo_prerelease}%{?dist}
License: (MPLv1.1 or LGPLv3+) and LGPLv3 and LGPLv2+ and BSD and (MPLv1.1 or GPLv2 or LGPLv2 or Netscape) and Public Domain and ASL 2.0 and Artistic and MPLv2.0 and CC0
Group: Applications/Productivity
URL: http://www.libreoffice.org/
@ -91,7 +92,7 @@ Source20: %{external_url}/48d647fbd8ef8889e5a7f422c1bfda94-clucene-core-2.
Source21: %{external_url}/lcms2-2.6.tar.gz
Source22: %{external_url}/36271d3fa0d9dec1632029b6d7aac925-liblangtag-0.5.1.tar.bz2
Source23: %{external_url}/d6eef4b4cacb2183f2bf265a5a03a354-boost_1_55_0.tar.bz2
Source24: %{external_url}/harfbuzz-0.9.23.tar.bz2
Source24: %{external_url}/harfbuzz-0.9.40.tar.bz2
Source25: %{external_url}/language-subtag-registry-2014-12-03.tar.bz2
%global bundling_options %{?bundling_options} --without-system-mythes --without-system-redland --without-system-libexttextcat --without-system-clucene --without-system-lcms2 --without-system-liblangtag --without-system-boost --without-system-harfbuzz
%endif
@ -99,12 +100,12 @@ Source26: %{external_url}/5821b806a98e6c38370970e682ce76e8-libcmis-0.5.0.t
Source27: %{external_url}/libcdr-0.1.1.tar.bz2
Source28: %{external_url}/libwpg-0.3.0.tar.bz2
Source29: %{external_url}/libwpd-0.10.0.tar.bz2
Source30: %{external_url}/libwps-0.3.1.tar.bz2
Source30: %{external_url}/libwps-0.4.0.tar.bz2
Source31: %{external_url}/libvisio-0.1.1.tar.bz2
Source32: %{external_url}/libmspub-0.1.2.tar.bz2
Source33: %{external_url}/libodfgen-0.1.3.tar.bz2
Source34: %{external_url}/libmwaw-0.3.4.tar.bz2
Source35: %{external_url}/libetonyek-0.1.1.tar.bz2
Source33: %{external_url}/libodfgen-0.1.4.tar.bz2
Source34: %{external_url}/libmwaw-0.3.5.tar.bz2
Source35: %{external_url}/libetonyek-0.1.2.tar.bz2
Source36: %{external_url}/libfreehand-0.1.0.tar.bz2
Source37: %{external_url}/libabw-0.1.1.tar.bz2
Source38: %{external_url}/librevenge-0.0.2.tar.bz2
@ -213,7 +214,7 @@ BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(libvisio-0.1)
BuildRequires: pkgconfig(libwpd-0.10)
BuildRequires: pkgconfig(libwpg-0.3)
BuildRequires: pkgconfig(libwps-0.3)
BuildRequires: pkgconfig(libwps-0.4)
BuildRequires: pkgconfig(mdds) >= 0.12.0
%endif
@ -324,10 +325,6 @@ Patch14: 0001-never-run-autogen.sh.patch
Patch15: 0001-add-X-TryExec-entries-to-desktop-files.patch
# not upstreamed
Patch16: 0001-disable-PSD-import-test-which-deadlocks-on-ARM.patch
Patch17: 0001-ppc64-do-not-use-asm-block-to-retrieve-args.patch
Patch18: 0001-java-dir-for-powepc64-and-powepc64le-can-differ.patch
Patch19: 0002-java-dir-for-powepc64-and-powepc64le-can-differ.patch
Patch20: 0001-add-missing-includes.patch
%define instdir %{_libdir}
%define baseinstdir %{instdir}/libreoffice
@ -1159,7 +1156,7 @@ done \
%{!?-l:%{error:-l must be present}}
%prep
%setup -q -n %{name}-%{version}%{?libo_prerelease} -b 1 -b 2
%setup -q -n %{name}-%{version}%{?libo__prerelease} -b 1 -b 2
rm -rf git-hooks */git-hooks
# set up git repo
@ -2431,6 +2428,9 @@ update-desktop-database %{_datadir}/applications &> /dev/null || :
%endif
%changelog
* Wed May 20 2015 David Tardon <dtardon@redhat.com> - 1:5.0.0.0-3.beta1
- update to 5.0.0 beta1
* Sat May 16 2015 Kalev Lember <kalevlember@gmail.com> - 1:5.0.0.0-2.alpha1
- Resolves: rhbz#1215800 install symbolic icons

@ -7,6 +7,6 @@ a7983f859eafb2677d7ff386a023bc40 a7983f859eafb2677d7ff386a023bc40-xsltml_2.1.2.
0168229624cfac409e766913506961a8 0168229624cfac409e766913506961a8-ucpp-1.3.2.tar.gz
12fb8b5b0d5132726e57b9b9fc7e22c4 libreoffice-multiliblauncher.sh
4b87018f7fff1d054939d19920b751a0 4b87018f7fff1d054939d19920b751a0-collada2gltf-master-cb1d97788a.tar.bz2
837f5d43e9f1b23ddc8c820f28b6a84c libreoffice-5.0.0.0.alpha1.tar.xz
3f1723cec3769d216f821db75072469d libreoffice-help-5.0.0.0.alpha1.tar.xz
2e81662bf2d7f20ca2ac6575e46e1f5a libreoffice-translations-5.0.0.0.alpha1.tar.xz
e2da251fe25cb4220cb59c136d2887b1 libreoffice-5.0.0.0.beta1.tar.xz
be3238a700633b48ef4113921fc22d75 libreoffice-help-5.0.0.0.beta1.tar.xz
52ac16844a757867d5d24ea764c3d72f libreoffice-translations-5.0.0.0.beta1.tar.xz

Loading…
Cancel
Save